Licensing
=========
SciPy is distributed under the modified (3-clause) BSD license.  All code,
documentation and other files added to SciPy by contributors is licensed under
this license, unless another license is explicitly specified in the source
code.  Contributors keep the copyright for code they wrote and submit for
inclusion to SciPy.

Other licenses that are compatible with the modified BSD license that SciPy
uses are 2-clause BSD, MIT and PSF.  Incompatible licenses are GPL, Apache and
custom licenses that require attribution/citation or prohibit use for
commercial purposes.

It regularly happens that PRs are submitted with content copied or derived from
unlicensed code.  Such contributions cannot be accepted for inclusion in SciPy.
What is needed in such cases is to contact the original author and ask him to
relicense his code under the modified BSD (or a compatible) license.  If the
original author agrees to this, add a comment saying so to the source files and
forward the relevant email to the scipy-dev mailing list.

What also regularly happens is that code is translated or derived from code in
R, Octave (both GPL-licensed) or a commercial application.  Such code also
cannot be included in SciPy.  Simply implementing functionality with the same
API as found in R/Octave/... is fine though, as long as the author doesn't look
at the original incompatibly-licensed source code.
